@@ -1,4 +1,5 @@
 import os
+from pathlib import Path
 from types import ModuleType
 from typing import List
 
@@ -7,6 +8,18 @@ from tortoise import Tortoise, BaseDBAsyncClient, connections
 
 from web_foundation.app.infrastructure.provide.initiator import Initiator
 from web_foundation.kernel import NamedContext
+from pydantic import BaseModel as PDModel
+
+
+class DbConfig(PDModel):
+    host: str
+    port: str
+    database: str
+    user: str
+    password: str
+    db_schema: str
+    with_migrations: bool
+    migrations_path: Path
 
 
 class DatabaseInitiator(Initiator):
@@ -37,7 +50,7 @@ class DatabaseInitiator(Initiator):
                         'user': self.db_conf.user,
                         'password': self.db_conf.password,
                         'database': self.db_conf.database,
-                        'schema': self.db_conf.schema,
+                        'schema': self.db_conf.db_schema,
                         'minsize': 1,
                         'maxsize': 5,
                     }
