@@ -1,73 +1,74 @@
 import asyncio
 from asyncio import Future
-from typing import List
+from typing import List, Type
 
 from aioprocessing import AioProcess
 
 from web_foundation.kernel import NamedContext
 from web_foundation.kernel.isolates.channel import IChannel
+from abc import ABCMeta, abstractmethod
 
 
-class Isolate:
+class Isolate(metaclass=ABCMeta):
     debug: bool
     _name: str
-    _named_isolates: List[str] = []
     _channel: IChannel
     _proc: AioProcess
     _async_mode: bool
     _named_ctx: NamedContext
+    _configured: bool
 
-    def __init__(self, async_mode: bool = False, debug: bool = False):
-        self._name = ""
-        self._channel = IChannel(self.name)
+    def __init__(self, async_mode: bool = False, debug: bool = False, configured: bool = False):
         self._async_mode = async_mode
-        self._proc = AioProcess(target=self._startup)
         self.debug = debug
+        self._configured = configured
 
     @property
     def name(self):
-        self._check_name()
         return self._name
 
-    @name.setter
-    def name(self, value: str):
-        if value in self._named_isolates:
-            raise AttributeError("Isolate.name nums be uniq")
-        self._name = value
-        self._named_isolates.append(value)
-
     @property
     def ctx(self) -> NamedContext:
         return self._named_ctx
 
+    @property
+    def configured(self) -> bool:
+        return self._configured
+
     @ctx.setter
     def ctx(self, value: NamedContext):
         self._named_ctx = value
 
-    def _check_name(self):
-        if self.name == "":
-            raise AttributeError("Isolate must be attached to App (App.add_isolate)")
+    @abstractmethod
+    async def _run(self):
+        pass
 
-    @property
-    def app_name(self):
-        return self.name.split(".")[0]
+    def _configure(self, *args, **kwargs):
+        pass
 
-    async def async_run(self):
-        raise NotImplementedError
+    def configure(self, name: str, *args, **kwargs):
+        self._name = name
+        self._proc = AioProcess(target=self._startup)
+        self._channel = IChannel(self._name)
+        self._configure(*args, **kwargs)
+        self._configured = True
 
-    def sync_run(self):
-        raise NotImplementedError
+    @abstractmethod
+    def _close(self, *args, **kwargs):
+        pass
+
+    def close(self, *args, **kwargs):
+        self._close(*args, **kwargs)
 
     def _startup(self):
-        if self._async_mode:
-            asyncio.run(self.async_run())
-        else:
-            self.sync_run()
+        asyncio.run(self._run())
 
     async def _exec(self):
         self._proc.start()
 
     def perform(self) -> Future:
+        if not self.configured:
+            raise RuntimeError(f"Isolate {self} not configured before start")
         return asyncio.ensure_future(self._exec())
 
     @property
