@@ -1,6 +1,7 @@
 from dataclasses import dataclass
 from enum import Enum
 from types import SimpleNamespace
+from typing import Dict
 
 from pydantic import BaseModel as PdModel
 from sanic import Request
@@ -16,7 +17,8 @@ class ProtectIdentity:
 
 @dataclass
 class InputContext:
-    r_attrs: SimpleNamespace
+    r_args: SimpleNamespace
+    r_kwargs: Dict
     named_ctx: NamedContext
     channel: IChannel
     dto: PdModel | None
